==> rdg-corp-sb-feeds-1.0.13-b23480.zip: changelog.md <==
# Changelog
- 1.0.13 (2023-09-05)
    * DEV-153-posts-are-not-inserting:
        - Fixed problems with IDs and logs.
- 1.0.12 (2023-09-01)
    * DEV-144-select-post-yype-and-url:
        - Remove unnecessary form code.
- 1.0.11 (2023-08-31)
    * DEV-144-select-post-yype-and-url:
        - URL configuration is allowed.
        - Allowed to select Post Type.
        - Taxonomy is selected/created.
- 1.0.10 (2023-08-10)
    * DEV-119-sb-feeds-mantenimiento-para-los-:
        - Log maintenance integrated.
- 1.0.9 (2023-07-12)
    * DEV-78-sports-feed-plugin-image-optimization-performance-fix:
        - Last optimized post is updated.
- 1.0.8 (2023-07-12)
    * DEV-78-sports-feed-plugin-image-optimization-performance:
        - Optimized last post configuration is added.
- 1.0.7 (2023-07-11)
    * DEV-80-sb-feeds-duplicate-posts:
        - The query is cleaned after the creation of each post.
- 1.0.6 (2023-07-8)
    * bugfix/DEV-79-sb-feeds-change-on-code:
        - Post Status commented.
- 1.0.5 (2023-06-27)
    * DEV-63-sb-sportsfeed-shortpixel-integrat:
        - Created cron configuration to optimize images.
- 1.0.4 (2023-06-26)
    * DEV-65-featured-images-fix:
        - Image conversion utility with shortpixel was implemented.
- 1.0.3 (2023-05-25)
    * DEV-35-assign-author-to-categories:
        - It is allowed to assign an author by category.
- 1.0.2 (2023-04-05)
    * SB-002-update-core-plugin:
        - Made multiple changes to how the plugin works.
- 1.0.1 (2023-03-31)
    * SB-001-create-composer-file:
        - Composer.json file is created.
- 1.0.0 (2023-03-31)
    * main:
        - Init commit.

==> rdg-corp-sb-feeds-1.0.15-5a0714.zip: changelog.md <==
# Changelog
- 1.0.15 (2023-09-27)
    * DEV-150-sb-feed-setting-minimum-words:
        - Feature finished.
- 1.0.14.2 (2023-09-27)
    * DEV-150-sb-feed-setting-minimum-words:
        - Second test with less code.
- 1.0.14.1 (2023-09-20)
    * DEV-150-sb-feed-setting-minimum-words:
        - Testing Minimum Content Words.
- 1.0.14 (2023-09-07)
    * DEV-153-posts-are-not-inserting:
        - The operation of the logs is verified.
- 1.0.13 (2023-09-05)
    * DEV-153-posts-are-not-inserting:
        - Fixed problems with IDs and logs.
- 1.0.12 (2023-09-01)
    * DEV-144-select-post-yype-and-url:
        - Remove unnecessary form code.
- 1.0.11 (2023-08-31)
    * DEV-144-select-post-yype-and-url:
        - URL configuration is allowed.
        - Allowed to select Post Type.
        - Taxonomy is selected/created.
- 1.0.10 (2023-08-10)
    * DEV-119-sb-feeds-mantenimiento-para-los-:
        - Log maintenance integrated.
- 1.0.9 (2023-07-12)
    * DEV-78-sports-feed-plugin-image-optimization-performance-fix:
        - Last optimized post is updated.
- 1.0.8 (2023-07-12)
    * DEV-78-sports-feed-plugin-image-optimization-performance:
        - Optimized last post configuration is added.
- 1.0.7 (2023-07-11)
    * DEV-80-sb-feeds-duplicate-posts:
        - The query is cleaned after the creation of each post.
- 1.0.6 (2023-07-8)
    * bugfix/DEV-79-sb-feeds-change-on-code:
        - Post Status commented.
- 1.0.5 (2023-06-27)
    * DEV-63-sb-sportsfeed-shortpixel-integrat:
        - Created cron configuration to optimize images.
- 1.0.4 (2023-06-26)
    * DEV-65-featured-images-fix:
        - Image conversion utility with shortpixel was implemented.
- 1.0.3 (2023-05-25)
    * DEV-35-assign-author-to-categories:
        - It is allowed to assign an author by category.
- 1.0.2 (2023-04-05)
    * SB-002-update-core-plugin:
        - Made multiple changes to how the plugin works.
- 1.0.1 (2023-03-31)
    * SB-001-create-composer-file:
        - Composer.json file is created.
- 1.0.0 (2023-03-31)
    * main:
        - Init commit.
